package com.ynet.life.loaf.jdbc;

import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.TableConfig;
import java.util.HashMap;
import java.util.Map;

/* loaded from: com_ynet_life_loaf_jdbc.jar:com/ynet/life/loaf/jdbc/LoafQueryFactory.class */
public class LoafQueryFactory {
    public static final TranFailException EXCEPTION_UNDEFINED_DATABASE_TYPE = new TranFailException("EBLN0000", "未定义的数据库类型");
    private static boolean QUERY_POOL_IS_ENABLE = false;
    private static Map QUERY_POOL = null;

    private LoafQueryFactory() {
    }

    public static LoafQueryInterface createQueryEntity(Map context, TableConfig tableConfig, Map resultKColl) throws TranFailException {
        return createQueryEntity(context, tableConfig, resultKColl, null);
    }

    public static LoafQueryInterface createQueryEntity(Map context, TableConfig tableConfig, Map resultKColl, String sortParam) throws TranFailException {
        if (QUERY_POOL_IS_ENABLE) {
            String key = tableConfig.getBusinessCode();
            LoafQueryInterface pooledQuery = getPooledQuery(key);
            LoafQueryInterface pooledQuery2 = pooledQuery;
            if (pooledQuery == null) {
                pooledQuery2 = getNewQuery(context, tableConfig, resultKColl, sortParam);
                QUERY_POOL.put(key, pooledQuery2);
            }
            return pooledQuery2;
        }
        return getNewQuery(context, tableConfig, resultKColl, sortParam);
    }

    private static LoafQueryInterface getPooledQuery(String key) {
        if (QUERY_POOL == null) {
            QUERY_POOL = new HashMap();
            return null;
        }
        return (LoafQueryInterface) QUERY_POOL.get(key);
    }

    public static LoafQueryInterface getNewQuery(Map context, TableConfig tableConfig, Map resultKColl, String sortParam) throws TranFailException {
        switch (LifeConstants.DB_TYPE) {
            case 1:
                return new LoafQueryOracle(context, tableConfig, resultKColl, sortParam);
            case 2:
                return new LoafQueryDB2(context, tableConfig, resultKColl, sortParam);
            case 3:
                return new LoafQuerySybase(context, tableConfig, resultKColl, sortParam);
            case 4:
                return new LoafQueryMysql(context, tableConfig, resultKColl, sortParam);
            default:
                Trace.logError("LOAF", "数据库类型[" + LifeConstants.DB_TYPE + "]未定义");
                throw EXCEPTION_UNDEFINED_DATABASE_TYPE;
        }
    }

    public static LoafQueryInterface getNewQuery(String queryFields, String sortParam, String querySql) throws TranFailException {
        switch (LifeConstants.DB_TYPE) {
            case 1:
                return new LoafQueryOracle(queryFields, sortParam, querySql);
            case 2:
                return new LoafQueryDB2(queryFields, sortParam, querySql);
            case 3:
                return new LoafQuerySybase(queryFields, sortParam, querySql);
            case 4:
                return new LoafQueryMysql(queryFields, sortParam, querySql);
            default:
                Trace.logError("LOAF", "数据库类型[" + LifeConstants.DB_TYPE + "]未定义");
                throw EXCEPTION_UNDEFINED_DATABASE_TYPE;
        }
    }
}
